package com.hippo.a7zip;

import java.io.Closeable;
import java.io.File;
import java.io.FileNotFoundException;
import java.io.IOException;
import java.io.InputStream;
import java.io.OutputStream;
import java.nio.charset.Charset;

public class InArchive implements Closeable {
    private final Charset charset;
    private long nativePtr;
    private final String password;

    @Bt
    public interface OpenVolumeCallback {
        SeekableInputStream openVolume(String str);
    }

    public class OpenVolumeInDirCallback implements OpenVolumeCallback {
        private final File dir;

        public OpenVolumeInDirCallback(File file) {
            this.dir = file;
        }

        @Override // com.hippo.a7zip.InArchive.OpenVolumeCallback
        public SeekableInputStream openVolume(String str) {
            try {
                return new FileSeekableInputStream(new File(this.dir, str));
            } catch (FileNotFoundException e) {
                throw new ArchiveException("Can't find the file<" + str + "> in dir<" + this.dir.getPath() + ">", e);
            }
        }
    }

    private InArchive(long j, Charset charset2, String str) {
        this.nativePtr = j;
        this.charset = charset2;
        this.password = str;
    }

    private static String applyCharsetToPassword(String str, Charset charset2) {
        if (str == null || charset2 == null) {
            return str;
        }
        byte[] bytes = str.getBytes(charset2);
        int length = bytes.length;
        char[] cArr = new char[length];
        for (int i = 0; i < length; i++) {
            cArr[i] = (char) (bytes[i] & 255);
        }
        return new String(cArr);
    }

    private static String applyCharsetToString(String str, Charset charset2) {
        if (str == null || charset2 == null) {
            return str;
        }
        int length = str.length();
        for (int i = 0; i < length; i++) {
            if (str.charAt(i) > 255) {
                return str;
            }
        }
        byte[] bArr = new byte[length];
        for (int i2 = 0; i2 < length; i2++) {
            bArr[i2] = (byte) str.charAt(i2);
        }
        return new String(bArr, charset2);
    }

    private void checkClosed() {
        if (this.nativePtr == 0) {
            throw new IllegalStateException("This InArchive is closed.");
        }
    }

    private static native void nativeClose(long j);

    private static native void nativeExtractEntry(long j, int i, String str, OutputStream outputStream);

    private static native boolean nativeGetArchiveBooleanProperty(long j, int i);

    private static native int nativeGetArchiveIntProperty(long j, int i);

    private static native long nativeGetArchiveLongProperty(long j, int i);

    private static native int nativeGetArchivePropertyType(long j, int i);

    private static native String nativeGetArchiveStringProperty(long j, int i);

    private static native boolean nativeGetEntryBooleanProperty(long j, int i, int i2);

    private static native int nativeGetEntryIntProperty(long j, int i, int i2);

    private static native long nativeGetEntryLongProperty(long j, int i, int i2);

    private static native int nativeGetEntryPropertyType(long j, int i, int i2);

    private static native InputStream nativeGetEntryStream(long j, int i);

    private static native String nativeGetEntryStringProperty(long j, int i, int i2);

    private static native String nativeGetFormatName(long j);

    private static native int nativeGetNumberOfEntries(long j);

    private static native long nativeOpen(SeekableInputStream seekableInputStream, String str, String str2, OpenVolumeCallback openVolumeCallback);

    public static InArchive open(File file) {
        try {
            return open(new FileSeekableInputStream(file), null, null, file.getName(), new OpenVolumeInDirCallback(file.getParentFile()));
        } catch (FileNotFoundException e) {
            StringBuilder a = C0894ia.a("Can't open the archive: ");
            a.append(file.getPath());
            throw new ArchiveException(a.toString(), e);
        }
    }

    @Override // java.io.Closeable, java.lang.AutoCloseable
    public void close() {
        long j = this.nativePtr;
        if (j != 0) {
            nativeClose(j);
            this.nativePtr = 0;
        }
    }

    public void extractEntry(int i, OutputStream outputStream) {
        extractEntry(i, this.password, outputStream);
    }

    public boolean getArchiveBooleanProperty(PropID propID) {
        checkClosed();
        return nativeGetArchiveBooleanProperty(this.nativePtr, propID.ordinal());
    }

    public int getArchiveIntProperty(PropID propID) {
        checkClosed();
        return nativeGetArchiveIntProperty(this.nativePtr, propID.ordinal());
    }

    public long getArchiveLongProperty(PropID propID) {
        checkClosed();
        return nativeGetArchiveLongProperty(this.nativePtr, propID.ordinal());
    }

    public PropType getArchivePropertyType(PropID propID) {
        int nativeGetArchivePropertyType = nativeGetArchivePropertyType(this.nativePtr, propID.ordinal());
        if (nativeGetArchivePropertyType < 0 || nativeGetArchivePropertyType >= PropType.values().length) {
            return PropType.UNKNOWN;
        }
        return PropType.values()[nativeGetArchivePropertyType];
    }

    public String getArchiveStringProperty(PropID propID) {
        return getArchiveStringProperty(propID, this.charset);
    }

    public boolean getEntryBooleanProperty(int i, PropID propID) {
        checkClosed();
        return nativeGetEntryBooleanProperty(this.nativePtr, i, propID.ordinal());
    }

    public int getEntryIntProperty(int i, PropID propID) {
        checkClosed();
        return nativeGetEntryIntProperty(this.nativePtr, i, propID.ordinal());
    }

    public long getEntryLongProperty(int i, PropID propID) {
        checkClosed();
        return nativeGetEntryLongProperty(this.nativePtr, i, propID.ordinal());
    }

    public String getEntryPath(int i) {
        return getEntryPath(i, this.charset);
    }

    public PropType getEntryPropertyType(int i, PropID propID) {
        int nativeGetEntryPropertyType = nativeGetEntryPropertyType(this.nativePtr, i, propID.ordinal());
        if (nativeGetEntryPropertyType < 0 || nativeGetEntryPropertyType >= PropType.values().length) {
            return PropType.UNKNOWN;
        }
        return PropType.values()[nativeGetEntryPropertyType];
    }

    public InputStream getEntryStream(int i) {
        return nativeGetEntryStream(this.nativePtr, i);
    }

    public String getEntryStringProperty(int i, PropID propID) {
        return getEntryStringProperty(i, propID, this.charset);
    }

    public String getFormatName() {
        checkClosed();
        return nativeGetFormatName(this.nativePtr);
    }

    public int getNumberOfEntries() {
        checkClosed();
        return nativeGetNumberOfEntries(this.nativePtr);
    }

    public boolean isClosed() {
        return this.nativePtr == 0;
    }

    public void extractEntry(int i, String str, OutputStream outputStream) {
        try {
            checkClosed();
            nativeExtractEntry(this.nativePtr, i, str, outputStream);
            try {
            } catch (IOException e) {
                throw new ArchiveException("Catch IOException while closing the OutputStream", e);
            }
        } finally {
            try {
                outputStream.close();
            } catch (IOException e2) {
                throw new ArchiveException("Catch IOException while closing the OutputStream", e2);
            }
        }
    }

    public String getArchiveStringProperty(PropID propID, Charset charset2) {
        checkClosed();
        String applyCharsetToString = applyCharsetToString(nativeGetArchiveStringProperty(this.nativePtr, propID.ordinal()), charset2);
        return applyCharsetToString != null ? applyCharsetToString : "";
    }

    public String getEntryPath(int i, Charset charset2) {
        return getEntryStringProperty(i, PropID.PATH, charset2);
    }

    public String getEntryStringProperty(int i, PropID propID, Charset charset2) {
        checkClosed();
        String applyCharsetToString = applyCharsetToString(nativeGetEntryStringProperty(this.nativePtr, i, propID.ordinal()), charset2);
        return applyCharsetToString != null ? applyCharsetToString : "";
    }

    public static InArchive open(SeekableInputStream seekableInputStream) {
        return open(seekableInputStream, null, null, null, null);
    }

    public static InArchive open(SeekableInputStream seekableInputStream, Charset charset2, String str, String str2, OpenVolumeCallback openVolumeCallback) {
        String applyCharsetToPassword = applyCharsetToPassword(str, charset2);
        long nativeOpen = nativeOpen(seekableInputStream, applyCharsetToPassword, str2, openVolumeCallback);
        if (nativeOpen != 0) {
            return new InArchive(nativeOpen, charset2, applyCharsetToPassword);
        }
        throw new ArchiveException("a7zip is buggy");
    }
}
