package com.hippo.image;

import android.graphics.Bitmap;
import android.graphics.Canvas;
import android.graphics.Paint;
import android.graphics.Rect;
import android.graphics.RectF;
import android.graphics.drawable.Animatable;
import android.os.Handler;
import android.os.Looper;
import java.io.InputStream;
import java.lang.ref.WeakReference;
import java.util.Iterator;
import java.util.LinkedHashSet;
import java.util.Set;

public final class ImageBitmap implements Animatable, Runnable {
    private static final Handler HANDLER = new Handler(Looper.getMainLooper());
    private int mAnimationReferences;
    private final Bitmap mBitmap;
    private final int mByteCount;
    private final Set mCallbackSet;
    private final int mFormat;
    private final int mFrameCount;
    private Image mImage;
    private final boolean mIsOpaque;
    private int mReferences;
    private boolean mRunning;

    public interface Callback {
        void invalidateImage(ImageBitmap imageBitmap);
    }

    private ImageBitmap(Image image) {
        this.mCallbackSet = new LinkedHashSet();
        int width = image.getWidth();
        int height = image.getHeight();
        Bitmap createBitmap = Bitmap.createBitmap(width, height, Bitmap.Config.ARGB_8888);
        this.mBitmap = createBitmap;
        image.render(0, 0, createBitmap, 0, 0, width, height, false, 0);
        this.mFormat = image.getFormat();
        this.mIsOpaque = image.isOpaque();
        this.mByteCount = image.getByteCount();
        int frameCount = image.getFrameCount();
        this.mFrameCount = frameCount;
        if (frameCount > 1) {
            this.mImage = image;
        } else {
            image.recycle();
        }
    }

    public static ImageBitmap create(Image image) {
        if (!image.isRecycled()) {
            try {
                return new ImageBitmap(image);
            } catch (OutOfMemoryError unused) {
                image.recycle();
            }
        }
        return null;
    }

    public static ImageBitmap decode(InputStream inputStream) {
        Image decode = Image.decode(inputStream, false);
        if (decode != null) {
            return create(decode);
        }
        return null;
    }

    private boolean notifyUpdate() {
        Iterator it = this.mCallbackSet.iterator();
        boolean z = false;
        while (it.hasNext()) {
            Callback callback = (Callback) ((WeakReference) it.next()).get();
            if (callback != null) {
                if (!z) {
                    z = true;
                    Image image = this.mImage;
                    image.render(0, 0, this.mBitmap, 0, 0, image.getWidth(), this.mImage.getHeight(), false, 0);
                }
                callback.invalidateImage(this);
            } else {
                it.remove();
            }
        }
        return z;
    }

    public void addCallback(Callback callback) {
        Iterator it = this.mCallbackSet.iterator();
        while (it.hasNext()) {
            Callback callback2 = (Callback) ((WeakReference) it.next()).get();
            if (callback2 == null) {
                it.remove();
            } else if (callback2 == callback) {
                return;
            }
        }
        this.mCallbackSet.add(new WeakReference(callback));
    }

    public void draw(Canvas canvas, float f, float f2, Paint paint) {
        if (!this.mBitmap.isRecycled()) {
            canvas.drawBitmap(this.mBitmap, f, f2, paint);
        }
    }

    public int getByteCount() {
        return this.mByteCount;
    }

    public int getFormat() {
        return this.mFormat;
    }

    public int getFrameCount() {
        return this.mFrameCount;
    }

    public int getHeight() {
        return this.mBitmap.getHeight();
    }

    public int getWidth() {
        return this.mBitmap.getWidth();
    }

    public boolean isAnimated() {
        return this.mImage != null;
    }

    public boolean isOpaque() {
        return this.mIsOpaque;
    }

    public boolean isRunning() {
        return this.mRunning;
    }

    public synchronized boolean obtain() {
        if (this.mBitmap.isRecycled()) {
            return false;
        }
        this.mReferences++;
        return true;
    }

    public synchronized void release() {
        int i = this.mReferences - 1;
        this.mReferences = i;
        if (i <= 0 && !this.mBitmap.isRecycled()) {
            this.mBitmap.recycle();
            Image image = this.mImage;
            if (image != null) {
                image.recycle();
            }
        }
    }

    public void removeCallback(Callback callback) {
        Iterator it = this.mCallbackSet.iterator();
        while (it.hasNext()) {
            Callback callback2 = (Callback) ((WeakReference) it.next()).get();
            if (callback2 == null) {
                it.remove();
            } else if (callback2 == callback) {
                it.remove();
                return;
            }
        }
    }

    public void run() {
        Image image;
        if (this.mBitmap.isRecycled() || (image = this.mImage) == null) {
            this.mRunning = false;
            return;
        }
        image.advance();
        if (!notifyUpdate()) {
            this.mRunning = false;
        } else if (this.mRunning) {
            HANDLER.postDelayed(this, (long) Math.max(0, this.mImage.getDelay()));
        }
    }

    public void start() {
        Image image;
        this.mAnimationReferences++;
        if (!this.mBitmap.isRecycled() && (image = this.mImage) != null && !this.mRunning) {
            this.mRunning = true;
            HANDLER.postDelayed(this, (long) Math.max(0, image.getDelay()));
        }
    }

    public void stop() {
        int i = this.mAnimationReferences - 1;
        this.mAnimationReferences = i;
        if (i <= 0) {
            this.mRunning = false;
            HANDLER.removeCallbacks(this);
        }
    }

    public void draw(Canvas canvas, Rect rect, Rect rect2, Paint paint) {
        if (!this.mBitmap.isRecycled()) {
            canvas.drawBitmap(this.mBitmap, rect, rect2, paint);
        }
    }

    public static ImageBitmap create(Bitmap bitmap) {
        if (!bitmap.isRecycled()) {
            return new ImageBitmap(bitmap);
        }
        return null;
    }

    public void draw(Canvas canvas, Rect rect, RectF rectF, Paint paint) {
        if (!this.mBitmap.isRecycled()) {
            canvas.drawBitmap(this.mBitmap, rect, rectF, paint);
        }
    }

    private ImageBitmap(Bitmap bitmap) {
        this.mCallbackSet = new LinkedHashSet();
        this.mFormat = 0;
        this.mBitmap = bitmap;
        this.mIsOpaque = !bitmap.hasAlpha();
        this.mByteCount = bitmap.getHeight() * bitmap.getRowBytes();
        this.mFrameCount = 1;
    }
}
